/* ----------------------------------------------------------------------------
 *
 * Raima Database Manager
 *
 * Copyright (c) 2012 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 *
 * ----------------------------------------------------------------------------
 */

/* EXAMPLE - obj06 for C++ */
/* This is the DDL (Database Definition Language) for a database implementing
 * two one-to-many relationship using network model sets.  The database will 
 * implement the beginnings of an mp3 collection.  The one (owner) side
 * of the relationship is an artist records.  The many (member) side of the 
 * relationship is the album record.  There will be a second set where the one
 * side is the album record and the many side is a track record.

 * The artist name and album title will be index so they can be retrieved in
 * sorted order.  The index will also allow an application to perform an
 * efficient search on those fields.
 * 
 * This schema file should be processed using the ddlp utility using the
 * -c and -cpp options to create an embedded dbd file.  The -c option will 
 * generate a c header file (obj06_db_dbd.h) and a c source file 
 * (obj06_db_dbd.c) which can be compiled into the application and used with 
 * the Open method to create the database dictionary if it does not already 
 * exist.
 */

database obj06_db 
{
    data file "obj06_db.d01" contains artist;
    data file "obj06_db.d02" contains album;
    data file "obj06_db.d03" contains track;
    key  file "obj06_db.k01" contains name;
    key  file "obj06_db.k02" contains title;

    record artist
    {
        key char    name[100];
    }

    record album
    {
        key char    title[100];
    }

    record track
    {
        char    name[100];
    }

    set artist_album
    {
        order last;
        owner artist;
        member album;
    }

    set album_track
    {
        order last;
        owner album;
        member track;
    }
}
